from setuptools import setup

setup(name='fund_dist',
      version='1.0',
      description='Fundamental distributions: Guassian, Binomial, Poisson',
      packages=['fund_dist'],
      author='Ozan Ersoy',
      author_email='ozan.ersoy+pypi@gmail.com',
      zip_safe=False)
